/* $Workfile: OsaLinuxC.h $   $Revision: 6 $    $Modtime: 8/18/05 9:37a $  */
/*******************************************************************************

  Odin TeleSystems Inc.

  OTX Telecom Adapter Driver

  @doc internal

  @module

  @normal Copyright (C) Odin TeleSystems Inc., 1998-2003, All Rights Reserved

*******************************************************************************/

/*---------------------------------------------------------------------------*\
  Note: starting from RedHat (kernel-2.4.18-14), OtxDrv gets compilation 
  errors, to cope with kernel and compiler (3.x) changes of RedHat 8.0 and 9.0, 
  functions using Linux kernel API in c++ files are segregated and put in 
  c files  
\*---------------------------------------------------------------------------*/

#ifndef OSA_LINUX_C_H
#define OSA_LINUX_C_H

#ifdef __cplusplus
extern "C" {
#endif

/*---------------------------------------------------------------------------*\
  
 from OsaLinuxCppRtl.h OsaLinuxCppRtl.cpp

\*---------------------------------------------------------------------------*/

#include "../OsaDef.h"
#include "OsaLinuxRtl.h"
                      
void OsaSpinLockImpl_Ctor(void **pSLock);
void OsaSpinLockImpl_Dtor(void **pSLock);
void OsaSpinLockImpl_Lock(void *pSLock, __u32 *flags);
void OsaSpinLockImpl_Unlock(void *pSLock, __u32 savedFlags);

void OsaEventImpl_Ctor(void **pWQHead);
void OsaEventImpl_Dtor(void **pWQHead);
void OsaEventImpl_wake_up(void **pWQHead);

void OsaSemaphoreImpl_Ctor(void **pSemaphore);
void OsaSemaphoreImpl_Dtor(void **pSemaphore);
void OsaSemaphoreImpl_Release(void **pSemaphore);
void OsaSemaphoreImpl_WaitForSemaphore(void **pSemaphore);


/*---------------------------------------------------------------------------*\  
 from OsaLinux.h and OsaLinux.cpp
\*---------------------------------------------------------------------------*/
   
void OsaLinuxUserEventDevice_Ctor(void **pWQHead);
void OsaLinuxUserEventDevice_Dtor(void **pWQHead);
void OsaLinuxUserEventDevice_wake_up(void **pWQHead);
void OsaLinuxUserEventDevice_poll_wait(struct file *pFl, 
                                       void **pWQHead, 
                                       struct poll_table_struct *pPTable);


/*---------------------------------------------------------------------------*\  
 from OsaLinux.h and OsaLinux.cpp
\*---------------------------------------------------------------------------*/


#define new ident_new
#define delete ident_delete
#define class ident_class
#define virtual ident_virtual			//KERNEL_VERSION(2,4,0): conflict with "virtual" in header file <linux/mm.h>  
#define namespace ident_namespace
#define private ident_private

#include <asm/poll.h>       //POLLIN | POLLRDNORM | POLLOUT | POLLWRNORM;
#include <linux/ioport.h>   //for struct resource

#undef new
#undef delete
#undef class
#undef virtual		// KERNEL_VERSION(2,4,0)
#undef namespace	// KERNEL_VERSION(2,4,0)
#undef private

// from <linux/pci.h>
#define   PCI_BASE_ADDRESS_0	0x10	/* 32 bits */ 
#define   PCI_BASE_ADDRESS_SPACE_IO 0x01 
#define   PCI_BASE_ADDRESS_MEM_MASK	(~0x0fUL) 
#define   PCI_BASE_ADDRESS_IO_MASK	(~0x03UL) 
#define   PCI_SUBSYSTEM_ID	0x2e 

int   OsaLinux_pci_present();  
void  OsaLinux_pci_read_config_word(void *dev, int where, u16 *val);
void  OsaLinux_pci_read_config_dword(void *dev, int where, u32 *val);
void  OsaLinux_pci_write_config_dword(void *dev, int where, u32 val);

void *OsaLinux_pci_dev_next(void *prev);
OsaUint16 OsaLinux_pci_dev_vendor(void *dev);
OsaUint16 OsaLinux_pci_dev_device(void *dev);
unsigned int OsaLinux_pci_dev_irq(void *dev);
unsigned int OsaLinux_pci_dev_resource_start(void *dev, int id);
void OsaLinux_pci_dev_enable(void *d);

/*---------------------------------------------------------------------------*\
  from OsaLinux.h and OsaLinux.cpp
  
  for RedHat 9.0; in RedHat 8.0, it compiles without modifying followings
\*---------------------------------------------------------------------------*/

void OsaLinux_MOD_INC_USE_COUNT(void);
void OsaLinux_MOD_DEC_USE_COUNT(void);

const void * Osalinux_inter_module_get(const char *sModule);
void OsaLinux_inter_module_register(const char *sName, const void *pFunName);
void OsaLinux_inter_module_unregister(const char *sName);

#ifdef __cplusplus
}
#endif

#endif //OSA_LINUX_C_H
